@@ -3,7 +3,7 @@
  *                                                                           *
  * Reads an Taylor-UUCP Log-/Statsfile, and generates a report out of it     *
  *                                                                           *
- * stats.c is (c) David Frey, 1995    					     *
+ * stats.c is (c) David Frey, 1995					     *
  *								             *
  * Modifications by Yves Arrouye, 1996                                       *
  *								             *
@@ -27,8 +27,6 @@
  * Initial revision
  * */
 
-static char RCSId[]="$Id: stats.c,v 1.0 1996/01/01 16:44:17 david Rel $";
- 
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -39,12 +37,11 @@ static char RCSId[]="$Id: stats.c,v 1.0 1996/01/01 16:44:17 david Rel $";
 #include <error.h>
 #include <errno.h>
 
-#include "uutraf.h"
+#include "utils.h"
+#include "stats.h"
+#include "config.h"
 
-extern int errno;
-
-void ReadStatsfile(char *statsfilename)
-/*
+/**
  * Reads in the stats file and builds a linked list of lines, containing
  * the original information.
  * This list is used by AnalyseLogfile, since it is not possible to get
@@ -53,6 +50,8 @@ void ReadStatsfile(char *statsfilename)
  * received file is not recorded in the log file.
  *
  */
+void readStatsFile(hostentry **hosttab,
+                   const char *statsfilename)
 {
   FILE *statsfile;
   statsentry *ptr;
@@ -62,78 +61,84 @@ void ReadStatsfile(char *statsfilename)
   char statsline[LINE_MAX+1];
   char *text;
   char text0[LINE_MAX+1];
-  struct tm time;
+  struct tm date;
   short int received;
   float duration;
   int sec100;
 
-  statsfile=fopen(statsfilename,"r"); 
-  if (statsfile == NULL)
-  {
+  statsfile=fopen(statsfilename,"r");
+  if (statsfile == NULL) {
     fprintf(stderr,"%s: can't open %s: %s\n",
-	    progname,statsfilename,strerror(errno));
+            progname,statsfilename,strerror(errno));
     exit(1);
   }
 
   /* Read and parse the Statsfile */
-  while (fgets(statsline,LINE_MAX,statsfile) != NULL)
-  {
+  while (fgets(statsline,LINE_MAX,statsfile) != NULL) {
     ptr = calloc(1,sizeof(statsentry));
-    if (ptr != NULL)
-    {
+    if (ptr != NULL) {
       sscanf(statsline,"%*s %8s (%d-%d-%d %d:%d:%d.%d) %[ -~]",
-	     hostname, &time.tm_year,&time.tm_mon, &time.tm_mday,
-	               &time.tm_hour,&time.tm_min, &time.tm_sec, 
-	               &sec100,text0);
+             hostname, &date.tm_year,&date.tm_mon, &date.tm_mday,
+             &date.tm_hour,&date.tm_min, &date.tm_sec,
+             &sec100,text0);
 
-      ptr->when = statstime(time,sec100);
+      ptr->when = statstime(date,sec100);
       text = &text0[0];
 
-      if (strncmp(text,FAILED,sizeof(FAILED)-1) == 0)
+      if (strncmp(text,FAILED,sizeof(FAILED)-1) == 0) {
         text += (sizeof(FAILED)-1);
-      
+      }
+
       ptr->received = received
-	= (strncmp(text,RECEIVED,sizeof(RECEIVED)-1) == 0);
+        = (strncmp(text,RECEIVED,sizeof(RECEIVED)-1) == 0);
       if (received) text += (sizeof(RECEIVED)-1);
       else          text += (sizeof(SENT)-1);
 
-      ptr->size = atol(text);          
-      while (isdigit(*text))  text++;
-      while (!isdigit(*text)) text++;  
+      ptr->size = atol(text);
+      while (isdigit(*text))  {
+        text++;
+      }
+
+      while (!isdigit(*text)) {
+        text++;
+      }
+
       duration = atof(text);
 
-      host = gethostentry(hostname);
-      if (received) 
-      { 
-	host->datarecnum++;  host->datarecbytes  += ptr->size; 
-	host->rectime += duration; 
+      host = getHostEntry(hosttab, hostname);
+      if (received) {
+        host->datarecnum++;
+        host->datarecbytes  += ptr->size;
+        host->rectime += duration;
+      } else {
+        host->datasentnum++;
+        host->datasentbytes += ptr->size;
+        host->senttime += duration;
       }
-      else          
-      { 
-	host->datasentnum++; host->datasentbytes += ptr->size; 
-	host->senttime += duration; 
-      }
-      ptr->next = host->statslist; host->statslist = ptr;
-    }
-    else
-    {
-      fprintf(stderr,"%s: Out of memory! (ReadStatsfile)\n",progname);
+
+      ptr->next = host->statslist;
+      host->statslist = ptr;
+    } else {
+      fprintf(stderr,"%s: out of memory! (readStatsfile)\n",progname);
       exit(1);
     }
   }
   fclose(statsfile);
 }
 
-statsentry *GetStatsEntry(statsentry *statslist, int received,
-    off_t size, etime_t when)
+/**
+ * get a stat entry
+ */
+const statsentry *getStatsEntry(const statsentry *statslist,
+                                int received,
+                                off_t size, time_t when)
 {
-  statsentry *ptr, *prevptr, *prevprevptr;
-  statsentry *statptr = 0;
+  const statsentry *ptr, *prevptr, *prevprevptr;
+  const statsentry *statptr = 0;
 
   ptr = statslist; prevptr = NULL;
   while ((ptr != NULL) && when < ptr->when
-    && (!statptr || !prevptr || prevptr->received != received))
-  {
+         && (!statptr || !prevptr || prevptr->received != received)) {
     if ((ptr->received == received) && ((ptr->size == size) || (size==0))) {
       statptr = ptr;
     }
