@@ -3,7 +3,7 @@
  *                                                                           *
  * Reads an Taylor-UUCP Log-/Statsfile, and generates a report out of it     *
  *                                                                           *
- * utils.c is (c) David Frey, 1995    					     *
+ * utils.c is (c) David Frey, 1995					     *
  *								             *
  * This program is free software; you can redistribute it and/or modify it   *
  * under the terms of the GNU General Public License as published by the     *
@@ -23,37 +23,34 @@
 #include <stdio.h>
 #include <time.h>
 
+#include "utils.h"
+
 /* $Log: utils.c,v $
  * Revision 1.0  1996/01/01 16:47:32  david
  * Initial revision
  * */
 
-static char RCSId[]="$Id: utils.c,v 1.0 1996/01/01 16:47:32 david Rel david $";
-
 char timestr[7];
 
-time_t unixtime(struct tm time)
+time_t unixtime(struct tm date)
 {
-  time.tm_mon--; time.tm_year -= 1900; /* Month 0..11, Year 1900... */
-  time.tm_isdst = -1;                  /* compute DST */
-  return mktime(&time);
+  date.tm_mon--; date.tm_year -= 1900; /* Month 0..11, Year 1900... */
+  date.tm_isdst = -1;                  /* compute DST */
+  return mktime(&date);
 }
 
-time_t statstime(struct tm time, time_t sec100)
+time_t statstime(struct tm date, time_t sec100)
 {
-  time.tm_mon--; time.tm_year -= 1900; /* Month 0..11, Year 1900... */
-  time.tm_isdst = -1;                  /* compute DST */
-  return mktime(&time)*100+sec100;
+  date.tm_mon--; date.tm_year -= 1900; /* Month 0..11, Year 1900... */
+  date.tm_isdst = -1;                  /* compute DST */
+  return mktime(&date)*100+sec100;
 }
 
 char *sec2str(time_t secs)
 {
   int min;
-  
+
   min = secs/  60; secs -=   min*60;
   sprintf(timestr,"%03d:%02ld",min,secs);
   return timestr;
 }
-
-
-
