@@ -3,7 +3,7 @@
  *                                                                           *
  * Reads an Taylor-UUCP Log-/Statsfile, and generates a report out of it     *
  *                                                                           *
- * uutraf.c is (c) David Frey, 1995					     *
+ * uutraf.c is (c) David Frey, 1995, 2007				     *
  *								             *
  * Modifications by Yves Arrouye, 1996                                       *
  *								             *
@@ -22,11 +22,6 @@
  * 675 Mass Ave, Cambridge, MA 02139, USA.                                   *
  *****************************************************************************/
 
-/* $Log: uutraf.c,v $ * Revision 1.0  1996/01/01 16:51:45  david * Initial
- * revision * */
-
-static char RCSId[] = "$Id: uutraf.c,v 1.0 1996/01/01 16:51:45 david Rel $";
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -40,6 +35,9 @@ static char RCSId[] = "$Id: uutraf.c,v 1.0 1996/01/01 16:51:45 david Rel $";
 #include <errno.h>
 
 #include "uutraf.h"
+#include "config.h"
+#include "stats.h"
+#include "utils.h"
 
 /* Options */
 static struct option const long_options[] =
@@ -54,16 +52,15 @@ static struct option const long_options[] =
 
 /* Globals */
 
-char *progname;					 /* name of the program */
-hostentry *hosttab;				 /* linked list of hosts */
-
+char *progname; /* name of the program */
 time_t startlogtime, stoplogtime;
 
-void AnalyzeLogfile(char *logfilename, int newsstats)
 /*
  * Analyze the Logfile. We got the file statistice already out of the
  * Stats-file.
  */
+void analyzeLogFile(hostentry **hosttab,
+                    const char *logfilename, int newsstats)
 {
   FILE *logfile;
   char logline[LINE_MAX + 1];
@@ -73,57 +70,58 @@ void AnalyzeLogfile(char *logfilename, int newsstats)
   char text0[LINE_MAX + 1];
 
   int sec100;
-  struct tm time;
+  struct tm date;
   off_t size;
   float cost;
-  statsentry *statsline;
+  const statsentry *statsline;
 
-  int outgoing;					 /* is it an outgoing call ? */
+  int outgoing; /* is it an outgoing call ? */
 
   host = NULL;
   outgoing = 0;
   logfile = fopen(logfilename, "r");
-  if (logfile == NULL)
-  {
+  if (logfile == NULL) {
     fprintf(stderr, "%s: can't open %s: %s\n",
-	    progname, logfilename, strerror(errno));
+            progname, logfilename, strerror(errno));
     exit(1);
   }
 
   /* Read, parse and analyse the Logfile */
   startlogtime = 0;
-  while (fgets(logline, LINE_MAX, logfile) != NULL)
-  {
+  while (fgets(logline, LINE_MAX, logfile) != NULL) {
     sscanf(logline, "%*s %8s %*s (%d-%d-%d %d:%d:%d.%d %*d) %[ -~]",
-	   hostname, &time.tm_year, &time.tm_mon, &time.tm_mday,
-	   &time.tm_hour, &time.tm_min, &time.tm_sec,
-	   &sec100, text0);
+           hostname, &date.tm_year, &date.tm_mon, &date.tm_mday,
+           &date.tm_hour, &date.tm_min, &date.tm_sec,
+           &sec100, text0);
+
+    if (hostname[0] != '-') {
+      host = getHostEntry(hosttab, hostname);
+    }
 
-    if (hostname[0] != '-')
-      host = gethostentry(hostname);
     text = &text0[0];
 
-    if (startlogtime == 0)
-      startlogtime = unixtime(time);
-    stoplogtime = unixtime(time);
+    if (startlogtime == 0) {
+      startlogtime = unixtime(date);
+    }
+
+    stoplogtime = unixtime(date);
 
     if ((strncmp(text0, CALLINGSYSTEM, sizeof(CALLINGSYSTEM) - 1) == 0) ||
-	(strncmp(text0, INCOMINGCALL, sizeof(INCOMINGCALL) - 1) == 0))
-    {
+	(strncmp(text0, INCOMINGCALL, sizeof(INCOMINGCALL) - 1) == 0)) {
       outgoing = (strncmp(text, CALLINGSYSTEM, sizeof(CALLINGSYSTEM) - 1) == 0);
 
-      if (outgoing)
+      if (outgoing) {
 	host->calls++;
+      }
     }
 
-    if ((strncmp(text0, LOGINSUCCESS, sizeof(LOGINSUCCESS) - 1) == 0))
-    {
-      if (outgoing)
+    if ((strncmp(text0, LOGINSUCCESS, sizeof(LOGINSUCCESS) - 1) == 0)) {
+      if (outgoing) {
 	host->pttcost += host->pttcostpercall;
+      }
     }
 
-    if ((strncmp(text0, RECEIVING, sizeof(RECEIVING) - 1) == 0))
-    {
+    if ((strncmp(text0, RECEIVING, sizeof(RECEIVING) - 1) == 0)) {
       int ismail = 0, isnews = 0;
       char *oparen, *cparen;
 
@@ -135,58 +133,51 @@ void AnalyzeLogfile(char *logfilename, int newsstats)
       isnews = (strncmp(text, "rnews ", 6) == 0);
       size = 0;
 
-      if ((oparen = strchr(text, '(')))
-      {
+      if ((oparen = strchr(text, '('))) {
 	size = strtol(oparen + 1, &cparen, 10);
-      }
-      else
+      } else {
 	cparen = NULL;
+      }
 
-      if (cparen == oparen)
-      {
-	statsline = GetStatsEntry(host->statslist, 1, size,
-				  statstime(time, sec100));
+      if (cparen == oparen) {
+	statsline = getStatsEntry(host->statslist, 1, size,
+				  statstime(date, sec100));
 
-	if (statsline)
-	{
+	if (statsline) {
 	  size = statsline->size;
 	}
       }
 
-      if (ismail)
-      {
+      if (ismail) {
 	host->mailrecbytes += size;
 	host->mailrecnum++;
 
 	cost = host->provfeepermail;
-	if (host->provfeeperkbmult)
-	{
+        if (host->provfeeperkbmult) {
 	  cost += ceil(size / KBYTE) * host->provfeepermailkb;
 	}
+
 	host->provmailcost += cost;
-      }
-      else if (isnews)
-      {
+      } else if (isnews) {
 	host->newsrecbytes += size;
 	host->newsrecnum++;
 
 	cost = host->provfeepernews;
-	if (host->provfeeperkbmult)
-	{
+
+        if (host->provfeeperkbmult) {
 	  cost += ceil(size / KBYTE) * host->provfeepernewskb;
 	}
+
 	host->provnewscost += cost;
-      }
-      else
-      {
+      } else {
 	host->filerecbytes += size;
 	host->filerecnum++;
 
 	cost = host->provfeeperfile;
-	if (host->provfeeperkbmult)
-	{
+        if (host->provfeeperkbmult) {
 	  cost += ceil(size / KBYTE) * host->provfeeperfilekb;
 	}
+
 	host->provfilecost += cost;
       }
 
@@ -195,8 +186,7 @@ void AnalyzeLogfile(char *logfilename, int newsstats)
       host->provcost += cost;
     }
 
-    if ((strncmp(text0, SENDING, sizeof(SENDING) - 1) == 0))
-    {
+    if ((strncmp(text0, SENDING, sizeof(SENDING) - 1) == 0)) {
       int ismail = 0, isnews = 0;
       char *oparen, *cparen;
 
@@ -208,57 +198,50 @@ void AnalyzeLogfile(char *logfilename, int newsstats)
 
       size = 0;
 
-      if ((oparen = strchr(text, '(')))
-      {
+      if ((oparen = strchr(text, '('))) {
 	size = strtol(oparen + 1, &cparen, 10);
-      }
-      else
+      } else {
 	cparen = NULL;
+      }
 
-      if (cparen == oparen)
-      {
-	statsline = GetStatsEntry(host->statslist, 1, size,
-				  statstime(time, sec100));
+      if (cparen == oparen) {
+	statsline = getStatsEntry(host->statslist, 1, size,
+				  statstime(date, sec100));
 
-	if (statsline)
-	{
+	if (statsline) {
 	  size = statsline->size;
 	}
-      }
-      if (ismail)
-      {
+      } 
+      
+      if (ismail) {
 	host->mailsentbytes += size;
 	host->mailsentnum++;
 
 	cost = host->provfeepermail;
-	if (host->provfeeperkbmult)
-	{
+        if (host->provfeeperkbmult) {
 	  cost += ceil(size / KBYTE) * host->provfeepermailkb;
 	}
+
 	host->provmailcost += cost;
-      }
-      else if (isnews)
-      {
+      } else if (isnews) {
 	host->newssentbytes += size;
 	host->newssentnum++;
 
 	cost = host->provfeepernews;
-	if (host->provfeeperkbmult)
-	{
+	if (host->provfeeperkbmult) {
 	  cost += ceil(size / KBYTE) * host->provfeepernewskb;
 	}
+
 	host->provmailcost += cost;
-      }
-      else
-      {
+      } else {
 	host->filesentbytes += size;
 	host->filesentnum++;
 
 	cost = host->provfeeperfile;
-	if (host->provfeeperkbmult)
-	{
+        if (host->provfeeperkbmult) {
 	  cost += ceil(size / KBYTE) * host->provfeeperfilekb;
 	}
+
 	host->provfilecost += cost;
       }
 
@@ -267,21 +250,23 @@ void AnalyzeLogfile(char *logfilename, int newsstats)
       host->provcost += cost;
     }
 
-    if (strncmp(text, CALLCOMPLETE, sizeof(CALLCOMPLETE) - 1) == 0)
-    {
+    if (strncmp(text, CALLCOMPLETE, sizeof(CALLCOMPLETE) - 1) == 0) {
       time_t connected;
 
       text += (sizeof(CALLCOMPLETE) - 1);
       connected = atol(text);
 
-      while (isdigit(*text))
+      while (isdigit(*text)) {
 	text++;
-      while (!isdigit(*text))
+      }
+
+      while (!isdigit(*text)) {
 	text++;
+      }
+
       size = atof(text);
 
-      if (outgoing)
-      {
+      if (outgoing) {
 	host->connected += connected;
 
 	cost = ceil(connected / 60.0) * host->provlinecostpermin;
@@ -297,10 +282,8 @@ void AnalyzeLogfile(char *logfilename, int newsstats)
 
   /* update cost entries */
 
-  for (host = hosttab; host; host = host->next)
-  {
-    if (!host->provfeeperkbmult)
-    {
+  for (host = *hosttab; host; host = host->next) {
+    if (!host->provfeeperkbmult) {
       cost = ceil((host->filerecbytes + host->filesentbytes) / KBYTE)
 	* host->provfeeperfilekb;
       host->provfilecost += cost;
@@ -320,10 +303,12 @@ void AnalyzeLogfile(char *logfilename, int newsstats)
     if (host->filerecnum != host->datarecnum
 	|| host->filesentnum != host->datasentnum
 	|| host->filerecbytes != host->datarecbytes
-	|| host->filesentbytes != host->datasentbytes)
-    {
+	|| host->filesentbytes != host->datasentbytes) {
 
-      fprintf(stderr, "%s: warning: incoherent file statistics for %s, costs may be wrong\n", progname, host->hostname);
+      fprintf(stderr,
+              "%s: warning: incoherent file statistics for %s," \
+              " costs may be wrong\n",
+              progname, host->hostname);
       cost = (host->datarecnum - host->filerecnum
 	      + host->datasentnum - host->filesentnum) * host->provfeeperfile
 	+ ceil((host->datarecbytes - host->filerecbytes
@@ -336,12 +321,12 @@ void AnalyzeLogfile(char *logfilename, int newsstats)
   }
 }
 
-void PrintResults(hostentry * hosttab, int newsstats)
 /*
  * Output out results
  */
+void printResults(hostentry **hosttab, int newsstats)
 {
-  hostentry *h;
+  const hostentry *h;
 
   off_t tfilerecbytes, tmailrecbytes, tnewsrecbytes, trecbytes;
   off_t tfilesentbytes, tmailsentbytes, tnewssentbytes, tsentbytes;
@@ -375,7 +360,7 @@ void PrintResults(hostentry * hosttab, int newsstats)
   tfilerecbytes = tfilesentbytes = tfilerecnum = tfilesentnum = 0;
   tprovfilecost = 0.0;
 
-  h = hosttab;
+  h = *hosttab;
   while (h != NULL)
   {
     if (h->connected > 0)
@@ -411,7 +396,7 @@ void PrintResults(hostentry * hosttab, int newsstats)
     printf("           Recd  Sent Total   Recd  Sent  Total                Provid.\n");
     printf("----------------------------------------------------------------------\n");
 
-    h = hosttab;
+    h = *hosttab;
     while (h != NULL)
     {
       if (h->connected > 0)
@@ -447,7 +432,7 @@ void PrintResults(hostentry * hosttab, int newsstats)
   tmailrecbytes = tmailsentbytes = tmailrecnum = tmailsentnum = 0;
   tprovmailcost = 0.0;
 
-  h = hosttab;
+  h = *hosttab;
   while (h != NULL)
   {
     if (h->connected > 0)
@@ -482,7 +467,7 @@ void PrintResults(hostentry * hosttab, int newsstats)
   trectime = tsenttime = 0.0;
   tprovcost = tpttcost = 0.0;
 
-  h = hosttab;
+  h = *hosttab;
   while (h != NULL)
   {
     if (h->connected > 0)
@@ -529,7 +514,7 @@ void PrintResults(hostentry * hosttab, int newsstats)
   tconnected = 0.0;
   tcalls = 0;
 
-  h = hosttab;
+  h = *hosttab;
   while (h != NULL)
   {
     if (h->connected > 0)
@@ -587,7 +572,11 @@ int main(int argc, char *argv[])
 
   int c;
 
-  char logfilename[FILENAME_MAX], statsfilename[FILENAME_MAX];
+  char logfilename[FILENAME_MAX];
+  char statsfilename[FILENAME_MAX];
+
+  hostentry *hosttab = NULL;
+  hostentry **pHosttab = &hosttab;
 
   progname = strrchr(argv[0], '/');	/* The program's name */
   if (progname)
@@ -641,11 +630,12 @@ int main(int argc, char *argv[])
     strcpy(statsfilename, argv[optind]);
   }
 
-  hosttab = BuildHostTable(CFGFILE);
-  ReadStatsfile(statsfilename);
 
-  AnalyzeLogfile(logfilename, newsstats);
-  PrintResults(hosttab, newsstats);
+  buildHostTable(pHosttab, CFGFILE);
+  readStatsFile(pHosttab, statsfilename);
+
+  analyzeLogFile(pHosttab, logfilename, newsstats);
+  printResults(pHosttab, newsstats);
 
   return (0);
 }
