@@ -3,7 +3,7 @@
  *                                                                           *
  * Reads an Taylor-UUCP Log-/Statsfile, and generates a report out of it     *
  *                                                                           *
- * uutraf.h is (c) David Frey, 1995    					     *
+ * uutraf.h is (c) David Frey, 1995, 2007                                    *
  *								             *
  * Modifications by Yves Arrouye, 1996                                       *
  *								             *
@@ -35,6 +35,9 @@
  * Initial revision
  * */
 
+#ifndef _UUTRAF_H
+#define _UUTRAF_H 1
+
 #define KBYTE 1000.0
 #define HOSTNAMELENGTH    8
 
@@ -53,18 +56,16 @@
 #define RECEIVING     "Receiving "
 #define SENDING       "Sending "
 #define EXECUTING     "Executing "
-#define ERROR	      "ERROR: "
+#define ERROR         "ERROR: "
 
 /* and in the Stats file */
 #define FAILED        "failed after "
 #define RECEIVED      "received "
 #define SENT          "sent "
 
-typedef unsigned long int etime_t;
-
 struct Statsentry
 {
-  etime_t when;
+  time_t when;
   int received;
   off_t   size;
   struct  Statsentry *next;
@@ -73,7 +74,7 @@ struct Statsentry
 struct Hostentry
 {
   char   hostname[HOSTNAMELENGTH+1];
-  off_t  datarecbytes, datasentbytes, filerecbytes, filesentbytes; 
+  off_t  datarecbytes, datasentbytes, filerecbytes, filesentbytes;
   off_t  mailrecbytes, mailsentbytes, newsrecbytes, newssentbytes;
   off_t  bruttobytes;
   uint   datarecnum, datasentnum,     filerecnum, filesentnum;
@@ -95,17 +96,16 @@ typedef struct Statsentry statsentry;
 
 /* Globals */
 
-extern char       *progname;		/* name of the program */
-extern hostentry  *hosttab;		/* linked list of hosts */
-extern statsentry *statslist;		/* linked list of statsentries */
+extern char       *progname; /* name of the program */
 
-extern char       *sec2str(time_t secs);
-extern time_t      unixtime(struct tm time);
-extern etime_t     statstime(struct tm time, time_t sec100);
+/* Declarations */
 
-extern hostentry  *gethostentry(char *hostname);
-extern hostentry  *BuildHostTable(char *cfgfilename);
-extern void        ReadStatsfile(char *statsfilename);
-extern void        ProcessStatsfile(hostentry *host);
-extern statsentry *GetStatsEntry(statsentry *statslist, int received,
-				 off_t size, etime_t when);
+void analyzeLogFile(hostentry **hosttab,
+                    const char *logfilename,
+                    int newsstats);
+
+void processStatsFile(const hostentry *host);
+
+void printResults(hostentry **hosttab, int newsstats);
+
+#endif /* _UUTRAF_H */
